[][src]Struct casperlabs_engine_shared::logging::log_settings::LogSettings

pub struct LogSettings {
    pub log_level_filter: LogLevelFilter,
    pub process_id: ProcessId,
    pub process_name: ProcessName,
    pub host_name: HostName,
}

container for logsettings from the host

Fields

log_level_filter: LogLevelFilterprocess_id: ProcessIdprocess_name: ProcessName

contains a string identifying the running process by convention should be a single token without whitespace

host_name: HostName

Methods

impl LogSettings[src]

pub fn new(process_name: &str, log_level_filter: LogLevelFilter) -> LogSettings[src]

Arguments

  • process_name - Name or key identifying the current process; should have no spaces or punctuations by convention
  • log_level_filter - Only log messages with priority >= to this log level will be logged

pub fn filter(&self, log_level: LogLevel) -> bool[src]

if lvl is less than settings loglevel, associated msg should be filtered out