[−][src]Module casperlabs_engine_shared::test_utils
Some functions to use in tests.
Functions
| create_empty_wasm_module_bytes | Returns the serialized form of an empty Wasm Module |
| mocked_account | Returns an account value paired with its key |
| wasm_costs_free | |
| wasm_costs_mock |